@@ -11,7 +11,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Encode qw< decode_utf8 encode_utf8 FB_CROAK >;
 use Scalar::Util 'blessed';
@@ -47,7 +47,7 @@ JE - Pure-Perl ECMAScript (JavaScript) Engine
 
 =head1 VERSION
 
-Version 0.008 (alpha release)
+Version 0.010 (alpha release)
 
 =head1 SYNOPSIS
 
@@ -812,18 +812,49 @@ __END__
 
 =head1 BUGS
 
+=item *
+
 The RegExp class is incomplete. The Date class is still nonexistent.
 
+=item *
+
 Functions objects do not always stringify properly. The body of the 
 function is
 missing. This produces warnings, too.
 
+=item *
+
 The JE::Scope class, which has an C<AUTOLOAD> sub that 
 delegates methods to the global object, does not yet implement 
 the C<can> method, so if you call $scope->can('to_string')
 you will get a false return value, even though scope objects I<can>
 C<to_string>.
 
+=item *
+
+JE::LValue's C<can> method returns the method that JE::LValue::AUTOLOAD 
+calls when methods are delegated. But that means that if you call C<can>'s
+return value, it's not the same as invoking a method, because a
+different object is passed:
+
+ $lv = $je->eval('this.document');
+ $lv->set({});
+
+ $lv->to_string; # passes a JE::Object to JE::Object's to_string method
+ $lv->can('to_string')->($lv);
+	# passes the JE::LValue to JE::Object's to_string method
+
+If this is a problem for anyone, I have a fix for it (returning a closure),
+but I think it would have a 
+performance
+penalty, so I don't want to fix it. :-(
+
+=item *
+
+C<hasOwnProperty> does not work properly with arrays and arguments objects.
+
+=item *
+
 The documentation is a bit incoherent. It probably needs a rewrite.
 
 =head1 PREREQUISITES
